//
//  VPNUAccountStatusShort.h
//  VPNUnlimitedSDK
//
//  Created by Vladimir Drozdin on 18.01.2022.
//  Copyright © 2022 KeepSolid. All rights reserved.
//

#import <VPNUnlimitedSDK/VPNUManager.h>

/*!
 @header
 @abstract Header file
 */

/*!
@interface VPNUAccountStatusShort
@abstract A model object which describes user's short account status.
*/
@interface VPNUAccountStatusShort : NSObject <NSCoding>

@property (readonly) BOOL registrationTrial;
@property (readonly) BOOL storeTrial;

@property (strong, readonly) NSDate *expiredDate;
/*!
 @brief Number of seconds left till account expiration.
 */
@property (readonly) long long secondsLeft;
/*!
 @brief A human-readable string which describes the time left till account expiration.
 */
@property (copy, readonly) NSString *timeLeftString;
/*!
 @brief A boolean value which indicates if account has lifetime subscription.
 */
@property (readonly, getter=isLifetime) BOOL lifetime;
/*!
 @brief A boolean value which indicates if the account in trial period.
 */
@property (readonly, getter=isExpired) BOOL expired;

- (id)initWithDict:(NSDictionary *)info;

@end

